<?php
 


class Limex_Advr_Block_Adminhtml_Order_NewVsReturning
    extends Limex_Advr_Block_Adminhtml_Order_Abstract
{

    public function _prepareLayout()
    {
        parent::_prepareLayout();
        
        $this->setHeaderText(Mage::helper('advr')->__('New vs Returning Customers'));

        return $this;
    }

    protected function _prepareChart()
    {
        $this->setChartType('column');

        $this->_initChart()
            ->setXAxisType('datetime')
            ->setXAxisField('period')
            ;

        return $this;
    }

    protected function _prepareGrid()
    {
        $this->_initGrid()
            ->setDefaultSort('period')
            ->setDefaultDir('asc')
            ->setDefaultLimit(100000)
            ->setPagerVisibility(false)
            // ->setFilterVisibility(false)
            ;

        return $this;
    }

    protected function _prepareToolbar()
    {
        $this->_initToolbar()
            ->setRangesVisibility(true)
            ;

        return $this;
    }

    protected function _prepareCollection()
    {
        $collection = Mage::getModel('advr/report_sales')
            ->setBaseTable('sales/order')
            ->setFilterData($this->getFilterData())
            ->selectColumns($this->getVisibleColumns())
            ->groupByColumn('period')
            ;

        return $collection;
    }

    public function getColumns()
    {
        $columns = array(
            'period' => array(
                'header'         => 'Period',
                'type'           => 'text',
                'index'          => 'period',
                'frame_callback' => array(Mage::helper('advr/callback'), 'period'),
                'totals_label'   => 'Total',
                'filter'         => false,
            ),

            'quantity_by_new_customers' => array(
                'header'         => 'Orders by new customers',
                'type'           => 'number',
                'chart'          => true,
            ),

            'sum_grand_total_by_new_customers' => array(
                'header'         => 'Grand Total by new customers',
                'type'           => 'number',
                'type'           => 'currency',
            ),

            'percent_new' => array(
                'header'         => 'Percent of new',
                'type'           => 'percent',
                'index'          => 'quantity_by_new_customers',
                'frame_callback' => array($this, 'percent'),
            ),

            'quantity_by_returning_customers' => array(
                'header'         => 'Orders by returning customers',
                'type'           => 'number',
                'chart'          => true,
            ),

            'sum_grand_total_by_returning_customers' => array(
                'header'         => 'Grand Total by returning customers',
                'type'           => 'number',
                'type'           => 'currency',
            ),

            'percent_returning' => array(
                'header'         => 'Percent of returning',
                'type'           => 'percent',
                'index'          => 'quantity_by_returning_customers',
                'frame_callback' => array($this, 'percent'),
            ),
        );

        return $columns;
    }

    public function percent($value, $row, $column)
    {
        $a = $row->getData('quantity_by_new_customers');
        $b = $row->getData('quantity_by_returning_customers');

        if ($b > 0) {
            $result = $a / ($a + $b);
        } else {
            $result = 1;
        }

        if ($b == $value) {
            $result = 1 - $result;
        }

        return sprintf("%.1f %%", $result * 100);
    }
}